import os

# Default logging level for kunegu and kunegu-searchresults packages
LOGGING_LEVEL = 'INFO'

# Whether to display the debug panel
DEBUG_SEARCH_RESULTS = True

# Whether to enable settings useful for development, like displaying stack traces
DEBUG = True

# Whether to profile the app. Requires installing the 'profile' setup.py extras.
PROFILE = bool(int(os.getenv('KUNEGUSR_PROFILE') or '0'))

# The number of search results displayed on a single page
RESULTS_PER_PAGE = 10

# Whether to show only one result per domain
ONE_RESULT_PER_DOMAIN = False

# Custom Flask settings
class FlaskSettings(object):
    pass

# The name of the default planet used to make search queries. Can be None (see below).
DEFAULT_PLANET_NAME = None

# The function should return the default planet used to make search queries, as a kunegu.planets.Planet object.
# If DEFAULT_PLANET_NAME is set, is uses the setting. Otherwise, it returns the first available planet.
# The function can be overriden to implement custom logic.
def get_default_planet():
    from kunegu import planets
    from kunegu import c

    if globals().get('DEFAULT_PLANET_NAME'):
        planet_name = globals()['DEFAULT_PLANET_NAME']
    else:
        planet_names = c.storage.select_planet_names(1)
        if not planet_names:
            raise ValueError('No DEFAULT_PLANET_NAME set and no stored planets')
        planet_name = planet_names[0]
    planet = planets.fetch_planet(planet_name)
    if not planet:
        raise ValueError('No default, existing planet configured')
    return planet

