from __future__ import division

from functools import update_wrapper

from flask import request, make_response

from kunegu.util import urlparse, urlencode


def request_arg_to_bool(arg):
    val = request.args.get(arg)
    if not val:
        return False
    return bool(int(val))

def set_query_param(url, param_name, param_value):
    pr = urlparse.urlparse(url)
    params_dict = urlparse.parse_qs(pr.query)
    params_dict[param_name] = param_value
    pr = pr._replace(query=urlencode(params_dict, True))
    return urlparse.urlunparse(pr)

def no_cache(f):
    def new_func(*args, **kwargs):
        resp = make_response(f(*args, **kwargs))
        resp.cache_control.no_cache = True
        return resp
    return update_wrapper(new_func, f)

def time_text(secs):
    secs = abs(secs)
    if secs < 120:
        return u'seconds'
    if secs < 3600:
        mins = secs // 60
        return u'%d minute%s' % (mins, '' if mins == 1 else 's')
    if secs < 86400 * 2:
        hours = secs // 3600
        return u'%d hour%s' % (hours, '' if hours == 1 else 's')
    if secs < 86400 * 60:
        days = secs // 86400
        return u'%d day%s' % (days, '' if days == 1 else 's')
    if secs < (86400 * 30) * 24:
        months = secs // (86400 * 30)
        return u'%d month%s' % (months, '' if months == 1 else 's')
    years = secs // (86400 * 365)
    return u'%s year%s' % (int(years), '' if years == 1 else 's')
