import datetime
from flask import Markup
from flask import request
from functools import partial

from kunegu import serialize
from kunegusr import ksrutil, ksrconfig


### registering globals and filters

GLOBALS = {}
FILTERS = {}

def add(d, fun, name=None):
    if name is None:
        name = fun.__name__
    d[name] = fun

add_global = partial(add, GLOBALS)
add_filter = partial(add, FILTERS)


### functions

def preserve_arguments(exclude=[], exclude_with_prefixes=[]):
    lines = []
    for arg, value in request.args.items():
        if arg in exclude:
            continue
        if any(arg.startswith(prefix) for prefix in exclude_with_prefixes):
            continue
        lines.append('<input type=hidden name="%s" value="%s">' % (arg, value or ''))
    return Markup('\n'.join(lines))

def time_diff(dt):
    td = datetime.datetime.utcnow() - dt
    secs = td.total_seconds()
    text = ksrutil.time_text(secs)
    if secs > 0:
        return u'%s ago' % text
    return u'In %s' % text


### register the functions

add_global(ksrconfig, 'ksrconfig')

add_global(ksrutil.set_query_param)
add_global(ksrutil.request_arg_to_bool)
add_global(preserve_arguments)
add_global(serialize.json_dumps_friendly)

add_filter(time_diff)
